# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Tree-DAG_Node
Version:	1.22
Release:	1.%{__distinit}%{__distvers}
Summary:	Class for representing nodes in a tree
Group:		Development/Libraries
License:	Artistic 2.0
URL:		http://search.cpan.org/dist/Tree-DAG_Node/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RS/RSAVAGE/Tree-DAG_Node-%{version}.tgz
Source1:	File-Temp-0.21.pm
Patch0:		Tree-DAG_Node-1.22-old-Test::More.patch
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Slurp::Tiny) >= 0.003
# META.* calls for 3.4 but 0.87 works fine
BuildRequires:	perl(File::Spec) >= 0.87
# Actually need version 0.19 of File::Temp for the newdir method; we bundle a later version if needed
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.45
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This class encapsulates/makes/manipulates objects that represent nodes
in a tree structure. The tree structure is not an object itself, but
is emergent from the linkages you create between nodes.  This class
provides the methods for making linkages that can be used to build up
a tree, while preventing you from ever making any kinds of linkages
which are not allowed in a tree (such as having a node be its own
mother or ancestor, or having a node have two mothers).

%prep
%setup -q -n Tree-DAG_Node-%{version}

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch0
%endif

# File::Temp 0.19 is needed for the newdir method (just for the test suite)
%if %(perl -MFile::Temp -e 'print $File::Temp::VERSION < 0.19 ? 1 : 0;')
mkdir -p inc/File
cp -p %{SOURCE1} inc/File/Temp.pm
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
%{_fixperms} %{buildroot}

%check
# Use our local File::Temp if necessary
[ -f inc/File/Temp.pm ] && export PERL5LIB=$(pwd)/inc

make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes README
%{perl_vendorlib}/Tree/
%{_mandir}/man3/Tree::DAG_Node.3pm*

%changelog
* Thu Feb 13 2014 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - Switch from File::Slurp to File::Slurp::Tiny (CPAN RT#92976)
- Update patch for building with old Test::More versions

* Fri Jan 31 2014 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
  - Bump File::Temp version requirement back up to 0.19, as that's the version
    that introduced the newdir() method, as used in the test suite

* Thu Jan 30 2014 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
  - Set pre-req File::Temp version # to 0 (back from 0.2301)

* Thu Sep 19 2013 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18
  - No changes, code or otherwise, except for the version # in the *.pm, this
    file, and Changelog.ini
  - Somehow a corrupted version got uploaded to search.cpan.org, so I've just
    changed the version # (the file on MetaCPAN was fine)

* Mon Sep 16 2013 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17
  - Write test temp files in :raw mode as well as utf-8, for MS Windows users
  - Take the opportunity to change all utf8 to utf-8, as per the docs for Encode,
    except for 'use warnings qw(FATAL utf8);', which doesn't accept utf-8 :-(

* Mon Sep  9 2013 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
  - Merge patch (slightly modified by me) from Tom Molesworth (CPAN RT#88501):
    - Remove 'use open qw(:std :utf8);' because of its global effect
    - Replace Perl6::Slurp with File::Slurp, using the latter's binmode option
      for the encoding
    - Fix docs where I'd erroneously said File::Slurp didn't support utf8

* Fri Sep  6 2013 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
  - Replace Path::Tiny with File::Spec, because the former's list of
    dependencies is soooo long :-( (CPAN RT#88435)
  - Move t/pod.t to xt/author/pod.t
- Explicitly run the author tests
- Reinstate support for old distributions back to FC-3
- Use a locally bundled copy of File::Temp for the test suite if necessary,
  as we need the newdir method, which is only available from version 0.19

* Thu Sep  5 2013 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
  - Document the copy() method
  - Patch the copy() method so it respects the {no_attribute_copy => 1} option
  - Add method read_tree(), for text files; it uses Perl6::Slurp, which
    supports utf8
  - Add methods read_attributes() and string2hashref($s) for use by read_tree()
  - Add t/read.tree.t to test read_tree()
  - Add t/tree.utf8.attributes.txt, in utf8, for use by t/read.tree.t
  - Add t/tree.with.attributes.txt and t/tree.without.attributes.txt for use by
    t/read.tree.t
  - Make Perl 5.8.1 a pre-req so we have access to the utf8 pragma
- Drop support for old distributions since we need Path::Tiny, which isn't
  available there

* Mon Aug 12 2013 Paul Howarth <paul@city-fan.org> - 1.13-1
- Update to 1.13
  - Change the values accepted for the no_attributes option from undef and 1
    to 0 and 1; if undef is used, it becomes 0, so pre-existing code will not
    change behaviour, whilst this makes it easier to pass 0 or 1 from the
    command line

* Tue Jul 16 2013 Paul Howarth <paul@city-fan.org> - 1.12-2
- Perl 5.18 rebuild

* Wed Jul  3 2013 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12
  - Change text in README referring to licence to match text in body of source,
    since it was in conflict with the Artistic Licence V 2.0
  - Rename CHANGES to Changes as per CPAN::Changes::SPEC
  - Various spelling fixes in the docs

* Mon Feb  4 2013 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
  - License clarified as Artistic 2.0 (CPAN RT#83088)

* Fri Feb  1 2013 Paul Howarth <paul@city-fan.org> - 1.10-1
- Update to 1.10
  - Look for but don't require Test::Pod ≥ 1.45 (CPAN RT#83077)
- Drop redundant BR: perl(Carp)

* Fri Nov  9 2012 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
  - No code changes
  - For pre-reqs such as strict, warnings, etc., which ship with Perl, set the
    version requirement to 0 (CPAN RT#80663)

* Fri Nov  2 2012 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07
  - New maintainer: Ron Savage
  - Pre-emptive apologies for any changes which are not back-compatible; no
    such problems are expected, but the introduction of new methods may
    disconcert some viewers
  - Fix CPAN RT#78858 and audit code for similar problems
  - Fix CPAN RT#79506
  - Rename ChangeLog to CHANGES, and add Changelog.ini
  - Replace all uses of cyclicity_fault() and Carp::croak with die
  - Remove unused methods: decommission_root(), cyclicity_allowed(),
    cyclicity_fault(), inaugurate_root(), no_cyclicity() and _update_links();
    OK - cyclicity_fault() was called once - it just died
  - Add methods: format_node(), hashref2string(), is_root(), node2string(),
    tree2string()
  - Reformat the POD big-time
  - Add Build.PL
  - Re-write Makefile.PL
  - Remove use vars(@ISA $Debug $VERSION), and replace latter 2 with 'our ...'
  - Rename t/00_about_verbose.t to t/about.perl.t
  - Add scripts/cut.and.paste.subtrees.pl (Warning: Some trees get into an
    infinite loop)
  - Add t/cut.and.paste.subtrees.t (Warning: Some trees get into an infinite
    loop)
  - Document the options (discouraged by Sean) supported in the call to
    new($hashref)
- This release by RSAVAGE -> update source URL
- BR: perl(Test::More) and perl(Test::Pod) ≥ 1.00
- Add patch to support building with Test::More < 0.88 on older distributions

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.06-13
- BR: perl(Carp) and perl(Test)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1.06-11
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.06-6
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 1.06-5
- Fix dist tag for RHEL-6 Beta

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> - 1.06-4
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu Oct  1 2009 Paul Howarth <paul@city-fan.org> - 1.06-3
- Define RPM macros in global scope

* Fri Nov 14 2008 Paul Howarth <paul@city-fan.org> - 1.06-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Mon Dec 10 2007 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Update source URL for new upstream maintainer

* Mon Mar 19 2007 Paul Howarth <paul@city-fan.org> - 1.05-4
- Fix dist tag for development builds and Fedora 7 onwards
- Remove %%{__perl_version} macro, used only once
- Define %%{__id_u} in a more portable way
- Use search.cpan.org download URL
- BuildRequire perl(ExtUtils::MakeMaker)
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros in command paths, hardcode them instead
- Fix argument order for find with -depth

* Fri Aug 26 2005 Paul Howarth <paul@city-fan.org> - 1.05-3
- Import from Fedora Extras

* Fri Jul  1 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.05-2
- Dist tag.

* Thu Dec 30 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:1.05-0.fdr.1
- Update to 1.05.

* Sun Jul 04 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:1.04-0.fdr.1
- First build.
